@@ -35,7 +35,7 @@ import gnomemusic.utils as utils
 class ArtistAlbumWidget(Gtk.Box):
 
     __gsignals__ = {
-        'tracks-loaded': (GObject.SignalFlags.RUN_FIRST, None, ()),
+        'songs-loaded': (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
     def __repr__(self):
@@ -44,10 +44,11 @@ class ArtistAlbumWidget(Gtk.Box):
     @log
     def __init__(self, media, player, model, header_bar,
                  selection_mode_allowed, size_group=None,
-                 selection_toolbar = None):
+                 cover_size_group=None):
         super().__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
 
         self._size_group = size_group
+        self._cover_size_group = cover_size_group
         scale = self.get_scale_factor()
         self._cache = AlbumArtCache(scale)
         self._loading_icon_surface = DefaultIcon(scale).get(
@@ -62,46 +63,49 @@ class ArtistAlbumWidget(Gtk.Box):
         self._header_bar = header_bar
         self._selection_mode = False
         self._selection_mode_allowed = selection_mode_allowed
-        self._selection_toolbar = selection_toolbar
-        self.songs = []
-        self._tracks = []
+
+        self._songs = []
 
         self._header_bar._select_button.connect(
             'toggled', self._on_header_select_button_toggled)
 
-        self.ui = Gtk.Builder()
-        self.ui.add_from_resource('/org/gnome/Music/ArtistAlbumWidget.ui')
+        ui = Gtk.Builder()
+        ui.add_from_resource('/org/gnome/Music/ArtistAlbumWidget.ui')
 
-        self.cover = self.ui.get_object('cover')
+        self.cover = ui.get_object('cover')
         self.cover.set_from_surface(self._loading_icon_surface)
-        self._disc_listbox = self.ui.get_object('disclistbox')
+
+        self._disc_listbox = ui.get_object('disclistbox')
         self._disc_listbox.set_selection_mode_allowed(
             self._selection_mode_allowed)
 
-        self.ui.get_object('title').set_label(self._album_title)
+        ui.get_object('title').set_label(self._album_title)
         creation_date = self._media.get_creation_date()
         if creation_date:
             year = creation_date.get_year()
-            self.ui.get_object('year').set_markup(
+            ui.get_object('year').set_markup(
                 '<span color=\'grey\'>{}</span>'.format(year))
 
         if self._size_group:
-            self._size_group.add_widget(self.ui.get_object('box1'))
+            self._size_group.add_widget(ui.get_object('box1'))
 
-        self.pack_start(self.ui.get_object('ArtistAlbumWidget'), True, True, 0)
+        if self._cover_size_group:
+            self._cover_size_group.add_widget(self.cover)
+
+        self.pack_start(ui.get_object('ArtistAlbumWidget'), True, True, 0)
 
         GLib.idle_add(self._update_album_art)
         grilo.populate_album_songs(self._media, self._add_item)
 
 
-    def create_disc_box(self, disc_nr, disc_tracks):
+    def create_disc_box(self, disc_nr, disc_songs):
         disc_box = DiscBox(self._model)
-        disc_box.set_tracks(disc_tracks)
+        disc_box.set_songs(disc_songs)
         disc_box.set_disc_number(disc_nr)
         disc_box.set_columns(2)
         disc_box.show_duration(False)
         disc_box.show_favorites(False)
-        disc_box.connect('track-activated', self._track_activated)
+        disc_box.connect('song-activated', self._song_activated)
         disc_box.connect('selection-toggle', self._selection_mode_toggled)
 
         return disc_box
@@ -135,18 +139,18 @@ class ArtistAlbumWidget(Gtk.Box):
                 self._player.actionbar.set_visible(True)
 
     @log
-    def _add_item(self, source, prefs, track, remaining, data=None):
-        if track:
-            self._tracks.append(track)
+    def _add_item(self, source, prefs, song, remaining, data=None):
+        if song:
+            self._songs.append(song)
             return
 
         discs = {}
-        for track in self._tracks:
-            disc_nr = track.get_album_disc_number()
+        for song in self._songs:
+            disc_nr = song.get_album_disc_number()
             if disc_nr not in discs.keys():
-                discs[disc_nr] = [track]
+                discs[disc_nr] = [song]
             else:
-                discs[disc_nr].append(track)
+                discs[disc_nr].append(song)
 
         for disc_nr in discs:
             disc = self.create_disc_box(disc_nr, discs[disc_nr])
@@ -155,7 +159,7 @@ class ArtistAlbumWidget(Gtk.Box):
                 disc.show_disc_label(False)
 
         if remaining == 0:
-            self.emit("tracks-loaded")
+            self.emit("songs-loaded")
 
     @log
     def _update_album_art(self):
@@ -167,7 +171,7 @@ class ArtistAlbumWidget(Gtk.Box):
         self.cover.set_from_surface(surface)
 
     @log
-    def _track_activated(self, widget, song_widget):
+    def _song_activated(self, widget, song_widget):
         if (not song_widget.can_be_played
                 or self._selection_mode):
             return
